@@ -1,6 +1,6 @@
 package CHI::Driver::Role::Universal;
 BEGIN {
-  $CHI::Driver::Role::Universal::VERSION = '0.46';
+  $CHI::Driver::Role::Universal::VERSION = '0.47';
 }
 use CHI::Constants qw(CHI_Meta_Namespace);
 use Moose::Role;
@@ -15,12 +15,14 @@ around 'get_namespaces' => sub {
     return grep { $_ ne CHI_Meta_Namespace } $self->$orig(@_);
 };
 
-around 'remove' => sub {
-    my ( $orig, $self, $key ) = @_;
+foreach my $method (qw(remove append)) {
+    around $method => sub {
+        my ( $orig, $self, $key, @rest ) = @_;
 
-    # Call transform_key before passing to remove
-    return $self->$orig( $self->transform_key($key) );
-};
+        # Call transform_key before passing to method
+        return $self->$orig( $self->transform_key($key), @rest );
+    };
+}
 
 1;
 
